# pg_summary

[![ci/cd](https://github.com/geocoug/pg-summary/actions/workflows/ci-cd.yaml/badge.svg)](https://github.com/geocoug/pg-summary/actions/workflows/ci-cd.yaml)

Create a summary of unique values for each column in a Postgres table or view and summarize results in an Excel workbook.
